@@ -1,5 +1,9 @@
-VERSION = "0.1.6"
+"""Constants for pymiele."""
+
+VERSION = "0.5.5"
 
 MIELE_API = "https://api.mcs3.miele.com/v1"
 OAUTH2_AUTHORIZE = "https://api.mcs3.miele.com/thirdparty/login"
 OAUTH2_TOKEN = "https://api.mcs3.miele.com/thirdparty/token"
+
+AIO_TIMEOUT = 15
